MCALF profiles
**************

This sub-package contains:

* Functions that can be used to model the spectra.
* Voigt profile with a variety of wrappers for different
  applications (`mcalf.profiles.voigt`).
* Gaussian profiles and skew normal distributions
  (`mcalf.profiles.gaussian`).

.. automodapi:: mcalf.profiles

.. automodapi:: mcalf.profiles.voigt

.. automodapi:: mcalf.profiles.gaussian
